# -*- encoding: utf-8 -*-
#
# Simple support for organizing vcs branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2
#
# Implementation of LazyCommandProxy:
#   (C) 2008 Lukáš Lalinský <lalinsky AT gmail com>

"""Organizing collection of vcs branches as complex project."""

version_info = (0, 4, 5, 'dev', 2)


from bzrlib import registry


class LazyCommandProxy(registry._LazyObjectGetter):

    def __init__(self, name, aliases, module):
        """Arguments sequence differs from Lukas version!!!
        (to match bzrlib.commands.plugin_cmds.register_lazy)
        """
        super(LazyCommandProxy, self).__init__(module, name)
        self.aliases = aliases
        self.__name__ = name

    def __call__(self, *args, **kwargs):
        return self.get_obj()(*args, **kwargs)

    def __getattr__(self, name):
        return getattr(self.get_obj(), name)


def register_commands(cmds_info):
    """Lazily register a command.

    @param cmds_info: list of 3-tuples (name, aliases, module):

        * name: Name of the command class; this Command subclass must
          exist in module
        * aliases: List of command aliases
        * module: Name of the module where is the command defined
    """
    try:
        from bzrlib.commands import plugin_cmds
        reg_func = plugin_cmds.register_lazy
    except (ImportError, AttributeError):
        from bzrlib.commands import register_command
        def reg_func(name, aliases, module):
            register_command(LazyCommandProxy(name, aliases, module))
    for name, aliases, module in cmds_info:
        reg_func(name, aliases, module)


register_commands([
    # (name, aliases, module)
    ('cmd_project_checkout', ['pco', 'pcheckout'],
                                        'bzrlib.plugins.scmproj.cli'),      # boxed
    ('cmd_project_commit',   ['pci', 'pcommit'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_fetch',    ['pfetch'],'bzrlib.plugins.scmproj.cli'),      # boxed
    ('cmd_project_get',      ['pget'],  'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_info',     ['pinfo'], 'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_init',     ['pinit'], 'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_publish',  ['pback', 'project-push', 'ppush'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_project_update',   ['pup', 'pupdate'],
                                        'bzrlib.plugins.scmproj.cli'),

    ('cmd_project_command',  ['pcmd', 'prun', 'pcommand'],
                                        'bzrlib.plugins.scmproj.cli'),
    ('cmd_chdir',            ['cd'],    'bzrlib.plugins.scmproj.cli'),

    # hidden
#    ('cmd_snapshot_collect', [],        'bzrlib.plugins.scmproj.cli'),
#    ('cmd_snapshot_commit',  [],        'bzrlib.plugins.scmproj.cli'),
#    ('cmd_snapshot_update',  [],        'bzrlib.plugins.scmproj.cli'),
    ])


def test_suite():
    from bzrlib.plugins.scmproj import tests
    return tests.test_suite()
