# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

import os

from bzrlib import (
    urlutils,
    )
from bzrlib.tests import TestCaseWithTransport
from bzrlib.tests.test_sftp_transport import TestCaseWithSFTPServer
from bzrlib.transport import get_transport

from bzrlib.plugins.scmproj import (
    project,
    )

class TestChdir(TestCaseWithTransport):

    def test_chdir_cwd(self):
        # I'm not paranoid just curious
        orig_cwd = os.getcwdu()
        os.chdir('.')
        os.chdir(orig_cwd)


class TestCli(TestCaseWithTransport):

    def test_project_init(self):
        # current directory
        stdout, stderr = self.run_bzr('project-init .')
        self.assertContainsRe(stdout,
            r'New ".scmproj" control branch intialized in current directory.')
        self.assertIsDirectory('.scmproj', get_transport('.'))
        # other directory
        stdout, stderr = self.run_bzr('pinit a')
        self.assertContainsRe(stdout,
            r'New ".scmproj" control branch intialized in "a".')
        self.assertIsDirectory('.scmproj', get_transport('a'))

    def test_project_get(self):
        self.build_tree(['x/'])
        out, err = self.run_bzr('pinit x/a')

        # derived project dir name
        out, err = self.run_bzr('project-get x/a')
        self.assertIsDirectory('.scmproj', get_transport('a'))

        # explicit project dir name
        out, err = self.run_bzr('pget x/a b')
        self.assertIsDirectory('.scmproj', get_transport('b'))


class TestCliRemote(TestCaseWithSFTPServer):

    def test_project_init(self):
        remote_url = self.get_url()
        stdout, stderr = self.run_bzr(['pinit', remote_url])
        self.assertContainsRe(stdout,
            r'New scmproj control branch intialized at "%s".' % remote_url)
        self.assertIsDirectory('.bzr', self.get_transport('.'))

    def test_project_get(self):
        remote_url = self.get_url('a')
        stdout, stderr = self.run_bzr(['pinit', remote_url])
        self.assertIsDirectory('.bzr', self.get_transport('a'))

        # derived project dir name
        out, err = self.run_bzr(['project-get', remote_url])
        self.assertIsDirectory('.scmproj', get_transport('a'))

        # explicit project dir name
        out, err = self.run_bzr(['project-get', remote_url, 'b'])
        self.assertIsDirectory('.scmproj', get_transport('b'))
