# Simple support for organizing bzr branches as complex project
#
# Copyright (C) 2008, 2009 Alexander Belchenko <bialix AT ukr net>
# License: GNU GPL v.2

from bzrlib.tests import TestCase
from bzrlib.plugins.scmproj.config import IndexCard
from bzrlib.plugins.scmproj.tests.whiteutils import reindentBlock


class TestIndexCard(TestCase):

    def test_default(self):
        ic = IndexCard()
        self.assertEquals(reindentBlock("""\
            # index card v1
            [INFO]
            [COMPONENTS]
            [SUBPROJECTS]
            """), ic.to_str())
        self.assertEqual(None, ic.alt)
        self.assertEqual(None, ic.subset)
        self.assertEqual(None, ic.get_component('foo'))
        self.assertEqual(None, ic.get_component('bar'))
        self.assertEqual(None, ic.get_subproject('spam'))

    def test_set_data(self):
        ic = IndexCard()
        ic.alt = 'DEFAULT'
        ic.subset = 'FULL'
        ic.set_component('foo', 'my-foo-revid')
        ic.set_component('bar', 'my-bar-revidd')
        ic.set_subproject('spam', 'eggs')
        self.assertEquals(reindentBlock("""\
            # index card v1
            [INFO]
            ALT = DEFAULT
            SUBSET = FULL
            [COMPONENTS]
            foo = my-foo-revid
            bar = my-bar-revidd
            [SUBPROJECTS]
            spam = eggs
            """), ic.to_str())

    def test_get_data(self):
        ic = IndexCard(reindentBlock("""\
            # index card v1
            [INFO]
            ALT = DEFAULT
            SUBSET = FULL
            [COMPONENTS]
            foo = my-foo-revid
            bar = my-bar-revidd
            [SUBPROJECTS]
            spam = eggs
            """))
        self.assertEqual('DEFAULT', ic.alt)
        self.assertEqual('FULL', ic.subset)
        self.assertEqual('my-foo-revid', ic.get_component('foo'))
        self.assertEqual('my-bar-revidd', ic.get_component('bar'))
        self.assertEqual('eggs', ic.get_subproject('spam'))
